==> otu-5000-17.02.tar: acterna/release/smartotu/app/serviceshelper/otau/SMTMacroSwitchDet.php <==
<?php
// *********************************************************
// NOTICE: All rights reserved. This material contains the
// trade secrets and confidential information of JDSU
// which embody substantial creative effort,
// ideas and expressions. No part of this material may be
// reproduced or transmitted in any form or by any means,
// electronic, mechanical, optical or otherwise, including
// photocopying and recording or in connection with any
// information storage or retrieval system, without
// specific written permission from JDSU
// Copyright JDSU 2012. All rights reserved.
// *********************************************************
namespace app\serviceshelper\otau;

use app\parser\SMTOtuSocket;

use app\parser\SMTOtuApi;

/**
 *
 * @author Sylvain Desplat
 *
 */
class SMTMacroSwitchDet extends SMTMacroSwitch
{
    /**
     * 
     * @param app\parser\SMTOtuSocket $socket
     */
    function __construct( SMTOtuSocket $socket )
    {
        parent::__construct($socket);
    }
    
    /**
     * Retrieve the switch GLOB endoded string
     * Used to apply the new config.
     */
    protected function retrieveGlobal()
    {
        $result = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, SMTSwitchManager::MACRO_SWITCH_ID, parent::GLOB ) );
        list( $device, $code, $test ) = explode(',', $result);        
        $this->setSwitchDecoder( parent::GLOB, $code );
        
        //retrieve OSU if needed: WARNING only retrieve OSU1 and OSU2 in simplified mode
        for ( $osuCount = 1; $osuCount <= $this->getSwitchDecoder( parent::GLOB)->getOSUCount(); $osuCount++)
        {
            $result = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, SMTSwitchManager::MACRO_SWITCH_ID, parent::OSU.$osuCount ) );
            list( $device, $code, $test ) = explode(',', $result);
            $this->setSwitchDecoder( parent::OSU.$osuCount, $code );
        }
         
        //distributor OSU is at address 31
        $osuDistributor = $this->getSwitchDecoder( parent::GLOB)->getOSUDistributor();
        if ( $osuDistributor != '' )
        {
            $result = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, SMTSwitchManager::MACRO_SWITCH_ID, $osuDistributor ) );
            list( $device, $code, $test ) = explode(',', $result);
            $this->setSwitchDecoder( parent::OSU_DISTRIBUTOR, $code );
        }        
    }

    /**
     * Retrieve internal switch and build Dto
     *  
     */
    protected function retrieveInternal()
    {
        $result = trim( $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, SMTSwitchManager::MACRO_SWITCH_ID, parent::INTERNAL ) ) );
        if ( $result != "")
        {
            list( $device, $code, $test ) = explode(',', $result);
            $code = trim($code);
            
            if ( $code != "")
            {
                $this->setSwitchDecoder( parent::INTERNAL, $code );        
                $this->serialNumber = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_SerialNum, SMTSwitchManager::MACRO_SWITCH_ID, parent::INTERNAL ) );
            }
        }
    }        
    
    /**
     * Retrieve internal switch and build the switch Dto
     * 
     * @param SMTOtuSocket $socket
     *
     * @return SMTMacroSwitchDet
     */
    static function retrieve( SMTOtuSocket $socket )   
    {
        $macroSwitchDet = new SMTMacroSwitchDet( $socket );
        $macroSwitchDet->retrieveGlobal();
    	$macroSwitchDet->retrieveInternal();    	  
    	$macroSwitchDet->buildSwitchDto( TRUE );
    	
    	return $macroSwitchDet;
    }    
}
?>

==> otu-5000-18.62.tar: acterna/release/smartotu/app/serviceshelper/otau/SMTMacroSwitchDet.php <==
<?php
// *********************************************************
// NOTICE: All rights reserved. This material contains the
// trade secrets and confidential information of JDSU
// which embody substantial creative effort,
// ideas and expressions. No part of this material may be
// reproduced or transmitted in any form or by any means,
// electronic, mechanical, optical or otherwise, including
// photocopying and recording or in connection with any
// information storage or retrieval system, without
// specific written permission from JDSU
// Copyright JDSU 2012. All rights reserved.
// *********************************************************
namespace app\serviceshelper\otau;

use app\parser\SMTOtuSocket;

use app\parser\SMTOtuApi;

/**
 *
 * @author Sylvain Desplat
 *
 */
class SMTMacroSwitchDet extends SMTMacroSwitch
{
    /**
     * 
     * @param app\parser\SMTOtuSocket $socket
     */
    function __construct( SMTOtuSocket $socket )
    {
        parent::__construct($socket);
    }
    
    /**
     * Retrieve the switch GLOB endoded string
     * Used to apply the new config.
     */
    protected function retrieveGlobal()
    {
        $result = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, SMTSwitchManager::MACRO_SWITCH_ID, parent::GLOB ) );
        list( $device, $code, $test ) = explode(',', $result);        
        $this->setSwitchDecoder( parent::GLOB, $code );
        
        // distributor OSX musn't be fetched twice
        $nbOsx = $this->getSwitchDecoder( parent::GLOB)->getOSUCount();
        if ( $nbOsx >= self::OSU_DISTRIBUTOR_INDEX)
        {
        	$nbOsx = self::OSU_DISTRIBUTOR_INDEX -1 ;
        }
        
        //retrieve OSU if needed: WARNING only retrieve OSU1 and OSU2 in simplified mode
        for ( $osuCount = 1; $osuCount <= $nbOsx; $osuCount++)
        {
            $result = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, SMTSwitchManager::MACRO_SWITCH_ID, parent::OSU.$osuCount ) );
            list( $device, $code, $test ) = explode(',', $result);
            $this->setSwitchDecoder( parent::OSU.$osuCount, $code );
        }
         
        //distributor OSU is at address 31
        $osuDistributor = $this->getSwitchDecoder( parent::GLOB)->getOSUDistributor();
        if ( $osuDistributor != '' )
        {
            $result = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, SMTSwitchManager::MACRO_SWITCH_ID, $osuDistributor ) );
            list( $device, $code, $test ) = explode(',', $result);
            $this->setSwitchDecoder( parent::OSU_DISTRIBUTOR, $code );
        }        
    }

    /**
     * Retrieve internal switch and build Dto
     *  
     */
    protected function retrieveInternal()
    {
        $result = trim( $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_desc, SMTSwitchManager::MACRO_SWITCH_ID, parent::INTERNAL ) ) );
        if ( $result != "")
        {
            list( $device, $code, $test ) = explode(',', $result);
            $code = trim($code);
            
            if ( $code != "")
            {
                $this->setSwitchDecoder( parent::INTERNAL, $code );        
                $this->serialNumber = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_SerialNum, SMTSwitchManager::MACRO_SWITCH_ID, parent::INTERNAL ) );
            }
        }
    }        
    
    /**
     * Retrieve internal switch and build the switch Dto
     * 
     * @param SMTOtuSocket $socket
     *
     * @return SMTMacroSwitchDet
     */
    static function retrieve( SMTOtuSocket $socket )   
    {
        $macroSwitchDet = new SMTMacroSwitchDet( $socket );
        $macroSwitchDet->retrieveGlobal();
    	$macroSwitchDet->retrieveInternal();    	  
    	$macroSwitchDet->buildSwitchDto( TRUE );
    	
    	return $macroSwitchDet;
    }    
}
?>
